@@ -1,6 +1,6 @@
 
 /*************************************************************************
- * Copyright (C) 2007-2011 Ruben Pollan Bella <meskio@sindominio.net>    *
+ * Copyright (C) 2007-2012 Ruben Pollan Bella <meskio@sindominio.net>    *
  *                                                                       *
  *  This file is part of TuDu.                                           *
  *                                                                       *
@@ -48,6 +48,7 @@ bool Config::load(const char* path)
 	file.open(path);
 	if (!file) return false;
 
+	tudu_file = L"";
 	sort_order = L"";
 	editor[0] = '\0';
 	while (!file.eof())
@@ -123,7 +124,7 @@ void Config::getOutContextOption(wstring& option, wstring& value)
 	}
 }
 
-bool Config::isYes(wstring& value)
+inline bool Config::isYes(wstring& value)
 {
 	if (L"yes" == value)
 		return true;
@@ -164,6 +165,9 @@ void Config::getGeneralOption(wstring& option, wstring& value)
 	if (L"us_dates" == option)
 		us_dates = isYes(value);
 
+	if (L"tudu_file" == option)
+		tudu_file = value.c_str();
+
 	if (L"sort_order" == option)
 		sort_order = value.c_str();
 
@@ -617,6 +621,11 @@ bool Config::useUSDates()
 	return us_dates;
 }
 
+wstring& Config::getTuduFile()
+{
+	return tudu_file;
+}
+
 wstring& Config::getSortOrder()
 {
 	return sort_order;
